@@ -18,21 +18,15 @@ __all__ = (
 )
 
 import logging
+import os
 import re
 import webbrowser
+from pathlib import Path
 from typing import List, Callable, Dict, Any
 
-import rnc.corpora_logging as clog
+import rnc.corpora_requests as creq
 
-log_file = clog.log_folder / f"{__name__}.log"
-formatter = clog.create_formatter()
-
-stream_handler = clog.create_stream_handler(formatter=formatter)
-file_handler = clog.create_file_handler(
-    log_path=log_file, formatter=formatter)
-
-logger = clog.create_logger(
-    __name__, logging.DEBUG, file_handler, stream_handler)
+logger = logging.getLogger("rnc")
 
 
 def mark_found_words(txt: str,
@@ -74,7 +68,7 @@ class Example:
         :param txt: str, example's text.
         :param src: str, example's source.
         :param ambiguation: str, example's ambiguation.
-        :param found_wordforms: list of str or str joined with ', ',
+        :param found_wordforms: list of str, None or str joined with ', ',
         example's found wordforms.
         :param doc_url: str, example's url.
         :return: None.
@@ -144,7 +138,7 @@ class Example:
 
     @property
     def data(self) -> Dict[str, Any]:
-        """ There're all fields except for doc_url.
+        """ There are all fields except for doc_url.
         Found wordforms joined with ', '.
 
         :return: dict with fields names and their values.
@@ -167,8 +161,8 @@ class Example:
         """
         if not isinstance(other, str):
             class_name = self.__class__.__name__
-            logger.warning(
-                f"As a txt to {class_name} set {type(other)}, str expected")
+            logger.warning(f"As a text to {class_name} "
+                           f"set {type(other)}, str expected")
 
         self._txt = other
 
@@ -181,10 +175,9 @@ class Example:
         :return: None.
         """
         if not isinstance(other, str):
-            if not isinstance(other, str):
-                class_name = self.__class__.__name__
-                logger.warning(
-                    f"As a src to {class_name} set {type(other)}, str expected")
+            class_name = self.__class__.__name__
+            logger.warning(f"As a source to {class_name} "
+                           f"set {type(other)}, str expected")
 
         self._src = other
 
@@ -206,13 +199,8 @@ class Example:
         """ Open the doc in the new tab of the default browser.
 
         :return: None.
-        :exception ValueError: URL is not like 'http...'
-        :exception: if something's wrong.
+        :exception: if something is wrong.
         """
-        if not self._doc_url.startswith('http'):
-            logger.exception(
-                f"Tried to open doc with wrong url: {self._doc_url}")
-            raise ValueError(f"Wrong URL: {self._doc_url}")
         try:
             webbrowser.open_new_tab(self._doc_url)
         except Exception:
@@ -228,7 +216,7 @@ class Example:
         :return: None.
         """
         self._txt = mark_found_words(
-            self._txt, self._found_wordforms, marker)
+            self.txt, self.found_wordforms, marker)
 
     def copy(self) -> Any:
         """
@@ -247,18 +235,23 @@ class Example:
 
     def __contains__(self,
                      item: Any) -> bool:
-        """ Checking that item is in the text.
-        Registers equaled.
+        """ Whether the item is in the text.
+        Registers equaled (if it is available).
 
         :param item: any type, item to check.
         :return: whether item is in text.
         """
-        if hasattr(item, 'lower') and hasattr(self.txt, 'lower'):
+        try:
             return item.lower() in self.txt.lower()
-        return item in self.txt
+        except AttributeError:
+            return item in self.txt
 
     def __str__(self) -> str:
-        """ Str format depends on the descendant.
+        """ Str format:
+            TEXT: ...
+            SOURCE: ...
+            AMBIGUATION: ...
+            FOUND WORDFORMS: ...
 
         :return: this str.
         """
@@ -269,7 +262,12 @@ class Example:
         return res
 
     def __repr__(self) -> str:
-        """ Str format depends on the descendant.
+        """ Str format:
+            text: ...
+            source: ...
+            ambiguation: ...
+            found wordforms: ...
+            URL: ...
 
         :return: this str.
         """
@@ -295,7 +293,7 @@ class Example:
 
 
 class KwicExample(Example):
-    __slots__ = '__left', '__center', '__right'
+    __slots__ = '_left', '_center', '_right'
 
     def __init__(self,
                  left: str,
@@ -304,7 +302,7 @@ class KwicExample(Example):
                  src: str,
                  found_wordforms: List[str] or str,
                  doc_url: str) -> None:
-        """ There's no ambiguation, it set with ''.
+        """ There is no ambiguation, it set with ''.
 
         :param left: str, example's left context.
         :param center: str, example's center context.
@@ -313,9 +311,9 @@ class KwicExample(Example):
         :param found_wordforms: list of str or str, example's found wordforms.
         :param doc_url: str, example's URL.
         """
-        self.__left = left
-        self.__center = center
-        self.__right = right
+        self._left = left
+        self._center = center
+        self._right = right
         super().__init__(self.txt, src, '', found_wordforms, doc_url)
 
     @property
@@ -323,21 +321,21 @@ class KwicExample(Example):
         """
         :return: str, example's left context.
         """
-        return self.__left
+        return self._left
 
     @property
     def center(self) -> Any:
         """
         :return: str, example's center context.
         """
-        return self.__center
+        return self._center
 
     @property
     def right(self) -> Any:
         """
         :return: str, example's right context.
         """
-        return self.__right
+        return self._right
 
     @property
     def txt(self) -> str:
@@ -349,7 +347,7 @@ class KwicExample(Example):
 
     @property
     def ambiguation(self) -> None:
-        msg = "There's no ambiguation in KWICExamples"
+        msg = "There is no ambiguation in KWICExamples"
         logger.error(msg)
         raise NotImplementedError(msg)
 
@@ -357,7 +355,7 @@ class KwicExample(Example):
     def data(self) -> Dict[str, Any]:
         """ All fields except for URL.
 
-        :return: dict with fields names and their values.
+        :return: dict with fields' names and their values.
         """
         data = {
             'left': self.left,
@@ -380,7 +378,7 @@ class KwicExample(Example):
             class_name = self.__class__.__name__
             logger.warning(f"As a left context to {class_name} "
                            f"set {type(other)}, str expected")
-        self.__left = other
+        self._left = other
 
     @center.setter
     def center(self,
@@ -394,7 +392,7 @@ class KwicExample(Example):
             class_name = self.__class__.__name__
             logger.warning(f"As a center context to {class_name} "
                            f"set {type(other)}, str expected")
-        self.__center = other
+        self._center = other
 
     @right.setter
     def right(self,
@@ -408,27 +406,27 @@ class KwicExample(Example):
             class_name = self.__class__.__name__
             logger.warning(f"As a right context to {class_name} "
                            f"set {type(other)}, str expected")
-        self.__right = other
+        self._right = other
 
     @txt.setter
     def txt(self,
             other: Any) -> None:
-        """ Text setter not implemented to kwic """
+        """ Text setter not implemented to KWICExamples """
         msg = "Text setter not implemented to KWICExamples"
         logger.error(msg)
         raise NotImplementedError(msg)
 
     def mark_found_words(self,
                          marker: Callable) -> None:
-        """ Mark found wordforms in all contexts using marker function.
+        """ Mark found wordforms in all contexts using marker.
 
         :param marker: function to mark found wordforms.
         :return: None.
         """
         words = self.found_wordforms
-        self.__left = mark_found_words(self.left, words, marker)
-        self.__center = mark_found_words(self.center, words, marker)
-        self.__right = mark_found_words(self.right, words, marker)
+        self._left = mark_found_words(self.left, words, marker)
+        self._center = mark_found_words(self.center, words, marker)
+        self._right = mark_found_words(self.right, words, marker)
 
 
 class MainExample(Example):
@@ -455,17 +453,16 @@ class ParallelExample(Example):
                  found_wordforms: List[str] or str = None,
                  doc_url: str = '') -> None:
         """
-        :param txt: dict of str, {lang: text}
+        :param txt: dict of str, {language tag: text}
         :param src: str, examples source.
         :param ambiguation: str, examples ambiguation.
         :param found_wordforms: list of str, examples found wordforms.
         :param doc_url: str, examples URL.
         """
         txt = txt or {}
-        found_wordforms = found_wordforms or []
 
         super().__init__(txt, src, ambiguation, found_wordforms, doc_url)
-        self.sort(lambda x: x[0])
+        self.sort()
 
     @property
     def txt(self) -> Dict[str, Any]:
@@ -479,17 +476,17 @@ class ParallelExample(Example):
     def txt(self,
             other: Any) -> None:
         """ Text setter not implemented to the ParallelExample """
-        msg = "Text setter not implemented to ParallelExamples. " \
-              "Try to use ex['lang'] instead"
+        msg = ("Text setter not implemented to ParallelExamples. "
+               "Try to use ex['language tag'] instead")
         logger.error(msg)
         raise NotImplementedError(msg)
 
     @property
     def data(self) -> Dict[str, Any]:
-        """ There're all fields except for doc_url.
+        """ There are all fields except for doc_url.
         Found wordforms joined with ', '.
 
-        :return: dict with fields names and their values.
+        :return: dict with fields' names and their values.
         """
         data = self.txt.copy()
         data['source'] = self.src
@@ -512,8 +509,8 @@ class ParallelExample(Example):
     @staticmethod
     def _best_src(f_src: str,
                   s_src: str) -> str:
-        """ Choose the best source, means there're
-        two translations in it.
+        """ Choose the best source, means
+        there are two translations in it.
 
         :param f_src: str, first source.
         :param s_src: str, second source.
@@ -526,13 +523,14 @@ class ParallelExample(Example):
     def sort(self,
              key: Callable = None,
              reverse: bool = False) -> None:
-        """ Sort txt dict, allowing the key to lang tags.
+        """ Sort txt dict, allowing the key to
+        items() from there.
 
-        :param key: callable, key to sort.
-        :param reverse: bool, whether sorting'll be in reversed order.
+        :param key: callable, key to sort. Sort by language tag by default.
+        :param reverse: bool, whether sorting will be in reversed order.
         :return: None.
         """
-        key = key or (lambda x: x)
+        key = key or (lambda items: items[0])
         data = sorted(self.txt.items(), key=key, reverse=reverse)
         self._txt = dict(data)
 
@@ -543,27 +541,28 @@ class ParallelExample(Example):
         txt_copy = self.txt.copy()
         return self.__class__(
             txt_copy, self.src, self.ambiguation,
-            self.found_wordforms, self.doc_url)
+            self.found_wordforms, self.doc_url
+        )
 
     def __contains__(self,
                      item: Any) -> bool:
-        """ Checking that item is in the text.
-        Registers equaled.
+        """ Whether the item is in the text.
+        Registers equaled (if it is available).
 
         :param item: any type, item to check.
         :return: whether item is in text.
         """
-        if (hasattr(item, 'lower') and
-                all(hasattr(i, 'lower') for i in self.txt.values())):
+        try:
             return any(item.lower() in i.lower() for i in self.txt.values())
-        return any(item in i for i in self.txt.values())
+        except AttributeError:
+            return any(item in i for i in self.txt.values())
 
     def __iadd__(self,
                  other: Any) -> Any:
         """ Concatenate two examples:
             – join the texts
 
-            – choose the best source, there're
+            – choose the best source, there are
             two translations there
 
             – choose where the text is disambiguated.
@@ -575,8 +574,9 @@ class ParallelExample(Example):
         :exception TypeError: if wrong type given.
         """
         if not isinstance(other, self.__class__):
-            msg = f"'+=' supported only with '{self.__class__}' " \
-                  f"objects, but {type(other)} given"
+            class_name = self.__class__.__name__
+            msg = (f"'+=' supported only with '{class_name}' "
+                   f"objects, but {type(other)} given")
             logger.error(msg)
             raise TypeError(msg)
 
@@ -603,18 +603,21 @@ class ParallelExample(Example):
 
     def __getattr__(self,
                     item: str) -> Any:
-        """ Get text in language.
+        """ Get the text in language.
 
-        :param item: str, language.
+        :param item: str, language tag.
         :return: str or None, text in the language if exists.
         """
-        return self.txt.get(item, None)
+        try:
+            return getattr(super(), item)
+        except AttributeError:
+            return self.txt.get(item, None)
 
     def __getitem__(self,
                     lang: str) -> Any:
         """ Get text in the language.
 
-        :param lang: str, language.
+        :param lang: str, language tag.
         :return: str or None, text in the language if exists.
         """
         return self.txt.get(lang, None)
@@ -622,12 +625,12 @@ class ParallelExample(Example):
     def __setitem__(self,
                     lang: str,
                     txt: Any) -> None:
-        """ Change text in the lang.
+        """ Change text in the language.
 
-        :param lang: str, lang tag.
+        :param lang: str, language tag.
         :param txt: any type, new text.
         :return: None.
-        :exception ValueError: if the text in the lang doesn't exist.
+        :exception ValueError: if the text in the language does not exist.
         """
         if not isinstance(txt, str):
             class_name = self.__class__.__name__
@@ -661,7 +664,84 @@ class AccentologicalExample(Example):
 
 
 class MultimodalExample(Example):
-    pass
+    def __init__(self,
+                 txt: str,
+                 src: str,
+                 ambiguation: str,
+                 found_wordforms: List[str] or str,
+                 doc_url: str,
+                 media_url: str,
+                 filename: str) -> None:
+        """
+        :param txt: str, example's text.
+        :param src: str, example's source.
+        :param ambiguation: str, example's ambiguation.
+        :param found_wordforms: list of str, None or str joined with ', ',
+        example's found wordforms.
+        :param doc_url: str, example's url.
+        :param media_url: str, URL to example's media file.
+        :param filename: str or Path, default name of the file (from RNC).
+        :return: None.
+        """
+        super().__init__(txt, src, ambiguation, found_wordforms, doc_url)
+        self._media_url = media_url
+        self._filepath = Path(filename)
+
+    @property
+    def filepath(self) -> Path:
+        """ Get the path to the local file.
+
+        :return: Path to the file.
+        """
+        return self._filepath
+
+    @filepath.setter
+    def filepath(self,
+                 other: str or Path) -> None:
+        """ Set new path to the local file.
+
+        ATTENTION: if the file exists it will not be moved to
+        the new path. You should call 'download_file()' again.
+
+        :param other: str or Path, new path to the local file.
+        :return: None.
+        """
+        self._filepath = Path(other)
+
+    @property
+    def columns(self) -> List[str]:
+        """ For csv writing.
+
+        :return: list of str, names of columns.
+        """
+        return super().columns + ['media_url', 'filename']
+
+    @property
+    def items(self) -> List[Any]:
+        """ For csv writing.
+
+        :return: list of any types, values of columns.
+        """
+        return super().items + [self._media_url, self.filepath]
+
+    def download_file(self) -> None:
+        """ Download the media file.
+
+        :return: None.
+        """
+        os.makedirs(self.filepath.parent, exist_ok=True)
+
+        data = [(self._media_url, str(self.filepath))]
+        try:
+            creq.download_docs(data)
+        except Exception:
+            raise
+
+    def copy(self) -> Any:
+        return self.__class__(
+            *self.data.values(), self.doc_url,
+            self._media_url, str(self.filepath)
+        )
 
 
 class MultiPARCExample(Example):
